# delimit;
set more off;
set mem 40m;

/* this do-file contains Stata commands that replicate results in the paper */

/****** Table 1 ******/

use mn_cand;

gen post=1 if year>1974;
recode post .=0;

gen pinc=inc*post;
gen pdnv=dnv*post;

quietly tab year, gen(yr);

reg d_sen inc pinc dnv pdnv yr* if uncontested!=1 & sameparty==0 & (num_cand<3|num_third==0) & D==1;

/****** Table 2 *****/

reg d_sen inc dnv if uncontested!=1 & sameparty==0 & num_cand<3 & D==1 & year==1958;

foreach i of numlist 62 66 70 72 {;
reg d_sen  inc dnv if uncontested!=1 & sameparty==0 & num_cand<3 & D==1 & year==19`i';

foreach i of numlist 76 80 82 86 90 {;
reg d_sen  inc dnv if uncontested!=1 & D==1 &  num_third==0 &  year==19`i';

/***** Table 3 ******/

use mn_sw, clear;
areg votepct inc if year>=1958 & year<=1972, a(year);
areg votepct inc if year>=1974 & year<=1990, a(year);

use mn_cand, clear;
areg d_sen inc dnv if year<1974 & uncontested!=1 & D==1 & sameparty==0 & (num_cand<3| num_third==0), a(year);
areg d_sen inc dnv if year>1974 & uncontested!=1 & D==1 & sameparty==0 & (num_cand<3| num_third==0), a(year);

use otherstates_sw, clear;
areg votepct inc if year>=1958 & year<=1972, a(stateyear);
areg votepct inc if year>=1974 & year<=1990, a(stateyear);

/***** Table A1 ******/

use mn_precinct;

tempname result1 result2;
tempfile dist_corr yr_corr;

postfile `result1' year dist corr1 corr2 using `dist_corr';

forvalues i=58(4)90 {;
forvalues j=1(1)67 {;
capture corr stsen1 stgov if year==19`i' & dist==`j';
local corr1=r(rho);
capture corr ussen stgov if year==19`i' & dist==`j';
local corr2=r(rho);
local yr=19`i';
local district=`j';
post `result1' (`yr') (`district') (`corr1') (`corr2');
};
};
postclose `result1';
use `dist_corr', clear;

replace corr1=abs(corr1);  
replace corr2=abs(corr2);

postfile `result2' year acorr1 acorr2 using `yr_corr';

forvalues i=58(4)90 {;
quietly sum corr1 if year==19`i';
local acorr1=r(mean);
quietly sum corr2 if year==19`i';
local acorr2=r(mean);
local yr=19`i';
post `result2' (`yr') (`acorr1') (`acorr2');
};
postclose `result2';
use `yr_corr', clear;

drop if year>1970 & year<1986;

list;

/* Figure 1 */

twoway (scatter acorr2 year, msymbol(O)) (scatter acorr1 year, msymbol(x)), 
legend(col(1) label (1 "Within Statewide Offices (Corr(SW))" ) label (2 "Between State Senate and Statewide Offices (Corr(SW, SS))")) 
xtitle("YEAR") ytitle("CORRELATION") xlab(1958 1962 1966 1970 1986 1990) ylabel(, nogrid) saving(figure1, replace);
